==> jc-1.4.0.tar.gz: java/util/logging/FileHandler.h <==
// public class java.util.logging.FileHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1a60b83d55f01707 java_util_logging_FileHandler
// @dep_class ddab973c71748871 java_util_logging_Handler
// @dep_class ed1d4146c2efe28e java_util_logging_StreamHandler

// header file dependencies
// @dep_header java_util_logging_StreamHandler

#include "java/util/logging/StreamHandler.h"

#ifndef _JC_java_util_logging_FileHandler_H_
#define _JC_java_util_logging_FileHandler_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_FileHandler$sub_refs	_jc_java_util_logging_FileHandler$sub_refs;
typedef struct _jc_java_util_logging_FileHandler$sub_nonrefs	_jc_java_util_logging_FileHandler$sub_nonrefs;
typedef struct _jc_java_util_logging_FileHandler$refs	_jc_java_util_logging_FileHandler$refs;
typedef struct _jc_java_util_logging_FileHandler$nonrefs	_jc_java_util_logging_FileHandler$nonrefs;
typedef struct _jc_java_util_logging_FileHandler$object	_jc_java_util_logging_FileHandler$object;

typedef struct _jc_java_util_logging_FileHandler$fields_struct	_jc_java_util_logging_FileHandler$fields_struct;
typedef const struct _jc_java_util_logging_FileHandler$vmethods	_jc_java_util_logging_FileHandler$vmethods;
typedef const struct _jc_java_util_logging_FileHandler$vtable	_jc_java_util_logging_FileHandler$vtable;
typedef const struct _jc_java_util_logging_FileHandler$vtype	_jc_java_util_logging_FileHandler$vtype;

// Class fields structure
struct _jc_java_util_logging_FileHandler$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24util__24logging__24XMLFormatter;
};
extern _jc_java_util_logging_FileHandler$fields_struct _jc_java_util_logging_FileHandler$class_fields;

// Constructors
extern void _jc_java_util_logging_FileHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_FileHandler$object *);
extern void _jc_java_util_logging_FileHandler$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_util_logging_FileHandler$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_lang_String$object *, jint, jint);
extern void _jc_java_util_logging_FileHandler$method$_init$d5fe1566b62ea5ab(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_lang_String$object *, jint, jint, jboolean);
extern void _jc_java_util_logging_FileHandler$method$_init$73d32b75516f7b43(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods
extern void _jc_java_util_logging_FileHandler$method$publish$f944ff14284acf4e(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_util_logging_LogRecord$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_FileHandler$method_info$publish$f944ff14284acf4e;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_util_logging_FileHandler$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_java_io_OutputStream$object *_jc_java_util_logging_FileHandler$method$createFileStream$a4fa84587327d131(_jc_env *, struct _jc_java_lang_String$object *, jint, jint, jboolean, jint);
extern struct _jc_java_lang_String$object *_jc_java_util_logging_FileHandler$method$replaceFileNameEscapes$fe0a72fe41ebae09(_jc_env *, struct _jc_java_lang_String$object *, jint, jint, jint);

// Virtual methods structure
struct _jc_java_util_logging_FileHandler$vmethods {
	void	(*publish$f944ff14284acf4e)(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_util_logging_LogRecord$object *);
};

// Vtable
struct _jc_java_util_logging_FileHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Handler$vmethods	java_util_logging_Handler;
	_jc_java_util_logging_StreamHandler$vmethods	java_util_logging_StreamHandler;
	_jc_java_util_logging_FileHandler$vmethods	java_util_logging_FileHandler;
};

// Vtype
struct _jc_java_util_logging_FileHandler$vtype {
	_jc_type			type;
	_jc_java_util_logging_FileHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_FileHandler$sub_refs {
	struct _jc_java_lang_String$object	*pattern;
};

// Reference instance fields (object)
struct _jc_java_util_logging_FileHandler$refs {
    _jc_java_util_logging_FileHandler$sub_refs	java_util_logging_FileHandler;
    _jc_java_util_logging_StreamHandler$sub_refs	java_util_logging_StreamHandler;
    _jc_java_util_logging_Handler$sub_refs	java_util_logging_Handler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_FileHandler$sub_nonrefs {
	jint	limit;
	jint	count;
	jboolean	append;
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_FileHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Handler$sub_nonrefs	java_util_logging_Handler;
    _jc_java_util_logging_StreamHandler$sub_nonrefs	java_util_logging_StreamHandler;
    _jc_java_util_logging_FileHandler$sub_nonrefs	java_util_logging_FileHandler;
};

// Object instance structure
struct _jc_java_util_logging_FileHandler$object {
	_jc_java_util_logging_FileHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_FileHandler$vtype	*vtype;
	_jc_java_util_logging_FileHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_FileHandler$vtype _jc_java_util_logging_FileHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_FileHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_FileHandler$class_object;

#endif	/* _JC_java_util_logging_FileHandler_H_ */

==> jc-1.4.5.tar.gz: java/util/logging/FileHandler.h <==
// public class java.util.logging.FileHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1a60b83d55f01707 java_util_logging_FileHandler
// @dep_class ddab973c71748871 java_util_logging_Handler
// @dep_class ed1d4146c2efe28e java_util_logging_StreamHandler

// header file dependencies
// @dep_header java_util_logging_StreamHandler

#include "java/util/logging/StreamHandler.h"

#ifndef _JC_java_util_logging_FileHandler_H_
#define _JC_java_util_logging_FileHandler_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_FileHandler$sub_refs	_jc_java_util_logging_FileHandler$sub_refs;
typedef struct _jc_java_util_logging_FileHandler$sub_nonrefs	_jc_java_util_logging_FileHandler$sub_nonrefs;
typedef struct _jc_java_util_logging_FileHandler$refs	_jc_java_util_logging_FileHandler$refs;
typedef struct _jc_java_util_logging_FileHandler$nonrefs	_jc_java_util_logging_FileHandler$nonrefs;
typedef struct _jc_java_util_logging_FileHandler$object	_jc_java_util_logging_FileHandler$object;

typedef struct _jc_java_util_logging_FileHandler$fields_struct	_jc_java_util_logging_FileHandler$fields_struct;
typedef const struct _jc_java_util_logging_FileHandler$vmethods	_jc_java_util_logging_FileHandler$vmethods;
typedef const struct _jc_java_util_logging_FileHandler$vtable	_jc_java_util_logging_FileHandler$vtable;
typedef const struct _jc_java_util_logging_FileHandler$vtype	_jc_java_util_logging_FileHandler$vtype;

// Class fields structure
struct _jc_java_util_logging_FileHandler$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24util__24logging__24XMLFormatter;
};
extern _jc_java_util_logging_FileHandler$fields_struct _jc_java_util_logging_FileHandler$class_fields;

// Constructors
extern void _jc_java_util_logging_FileHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_FileHandler$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_FileHandler$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_FileHandler$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_FileHandler$method$_init$d5fe1566b62ea5ab(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_lang_String$object *, jint, jint, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_FileHandler$method$_init$73d32b75516f7b43(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_logging_FileHandler$method$publish$f944ff14284acf4e(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_FileHandler$method_info$publish$f944ff14284acf4e;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_util_logging_FileHandler$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_io_OutputStream$object *_jc_java_util_logging_FileHandler$method$createFileStream$a4fa84587327d131(_jc_env *, struct _jc_java_lang_String$object *, jint, jint, jboolean, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_logging_FileHandler$method$replaceFileNameEscapes$fe0a72fe41ebae09(_jc_env *, struct _jc_java_lang_String$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_logging_FileHandler$vmethods {
	void	(*publish$f944ff14284acf4e)(_jc_env *, struct _jc_java_util_logging_FileHandler$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_logging_FileHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Handler$vmethods	java_util_logging_Handler;
	_jc_java_util_logging_StreamHandler$vmethods	java_util_logging_StreamHandler;
	_jc_java_util_logging_FileHandler$vmethods	java_util_logging_FileHandler;
};

// Vtype
struct _jc_java_util_logging_FileHandler$vtype {
	_jc_type			type;
	_jc_java_util_logging_FileHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_FileHandler$sub_refs {
	struct _jc_java_lang_String$object	*pattern;
};

// Reference instance fields (object)
struct _jc_java_util_logging_FileHandler$refs {
    _jc_java_util_logging_FileHandler$sub_refs	java_util_logging_FileHandler;
    _jc_java_util_logging_StreamHandler$sub_refs	java_util_logging_StreamHandler;
    _jc_java_util_logging_Handler$sub_refs	java_util_logging_Handler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_FileHandler$sub_nonrefs {
	jint	limit;
	jint	count;
	jboolean	append;
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_FileHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Handler$sub_nonrefs	java_util_logging_Handler;
    _jc_java_util_logging_StreamHandler$sub_nonrefs	java_util_logging_StreamHandler;
    _jc_java_util_logging_FileHandler$sub_nonrefs	java_util_logging_FileHandler;
};

// Object instance structure
struct _jc_java_util_logging_FileHandler$object {
	_jc_java_util_logging_FileHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_FileHandler$vtype	*vtype;
	_jc_java_util_logging_FileHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_FileHandler$vtype _jc_java_util_logging_FileHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_FileHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_FileHandler$class_object;

#endif	/* _JC_java_util_logging_FileHandler_H_ */
